==> trilinos_9.0.3.dfsg.orig.tar.gz: trilinos-9.0.3.dfsg.orig/packages/thyra/src/interfaces/operator_vector/ana/extended/Thyra_ScaledAdjointLinearOpBase.hpp <==
// @HEADER
// ***********************************************************************
// 
//    Thyra: Interfaces and Support for Abstract Numerical Algorithms
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef THYRA_SCALED_ADJOINT_LINEAR_OP_BASE_HPP
#define THYRA_SCALED_ADJOINT_LINEAR_OP_BASE_HPP

#include "Thyra_ScaledAdjointLinearOpBaseDecl.hpp"
#include "Thyra_LinearOpBase.hpp"

template<class Scalar>
void Thyra::unwrap(
  const LinearOpBase<Scalar>      &Op
  ,Scalar                         *scalar
  ,EOpTransp                        *transp
  ,const LinearOpBase<Scalar>*    *origOp
  )
{
#ifdef TEUCHOS_DEBUG
  TEST_FOR_EXCEPT( scalar==NULL );
  TEST_FOR_EXCEPT( transp==NULL );
  TEST_FOR_EXCEPT( origOp==NULL );
#endif
  typedef Teuchos::ScalarTraits<Scalar>  ST;
  const ScaledAdjointLinearOpBase<Scalar>
    *saOp = dynamic_cast<const ScaledAdjointLinearOpBase<Scalar>*>(&Op);
  if(saOp) {
    *scalar = saOp->overallScalar();
    *transp = saOp->overallTransp();
    *origOp = &*saOp->getOrigOp();
  }
  else {
    *scalar = ST::one();
    *transp = NOTRANS;
    *origOp = &Op;
  }
}

template<class Scalar>
void Thyra::unwrap(
  const Teuchos::RCP<const LinearOpBase<Scalar> >     &Op
  ,Scalar                                                     *scalar
  ,EOpTransp                                                    *transp
  ,Teuchos::RCP<const LinearOpBase<Scalar> >          *origOp
  )
{
#ifdef TEUCHOS_DEBUG
  TEST_FOR_EXCEPT( scalar==NULL );
  TEST_FOR_EXCEPT( transp==NULL );
  TEST_FOR_EXCEPT( origOp==NULL );
#endif
  typedef Teuchos::ScalarTraits<Scalar>  ST;
  Teuchos::RCP<const ScaledAdjointLinearOpBase<Scalar> >
    saOp = Teuchos::rcp_dynamic_cast<const ScaledAdjointLinearOpBase<Scalar> >(Op);
  if(saOp.get()) {
    *scalar = saOp->overallScalar();
    *transp = saOp->overallTransp();
    *origOp = saOp->getOrigOp();
  }
  else {
    *scalar = ST::one();
    *transp = NOTRANS;
    *origOp = Op;
  }
}

#endif	// THYRA_SCALED_ADJOINT_LINEAR_OP_BASE_HPP

==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/thyra/src/interfaces/operator_vector/ana/extended/Thyra_ScaledAdjointLinearOpBase.hpp <==
// @HEADER
// ***********************************************************************
// 
//    Thyra: Interfaces and Support for Abstract Numerical Algorithms
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef THYRA_SCALED_ADJOINT_LINEAR_OP_BASE_HPP
#define THYRA_SCALED_ADJOINT_LINEAR_OP_BASE_HPP

#include "Thyra_ScaledAdjointLinearOpBaseDecl.hpp"
#include "Thyra_LinearOpBase.hpp"


template<class Scalar>
void Thyra::unwrap(
  const LinearOpBase<Scalar> &Op,
  Scalar *scalar,
  EOpTransp *transp,
  const LinearOpBase<Scalar>* *origOp
  )
{
#ifdef TEUCHOS_DEBUG
  TEST_FOR_EXCEPT( scalar==NULL );
  TEST_FOR_EXCEPT( transp==NULL );
  TEST_FOR_EXCEPT( origOp==NULL );
#endif
  typedef Teuchos::ScalarTraits<Scalar>  ST;
  const ScaledAdjointLinearOpBase<Scalar>
    *saOp = dynamic_cast<const ScaledAdjointLinearOpBase<Scalar>*>(&Op);
  if(saOp) {
    *scalar = saOp->overallScalar();
    *transp = saOp->overallTransp();
    *origOp = &*saOp->getOrigOp();
  }
  else {
    *scalar = ST::one();
    *transp = NOTRANS;
    *origOp = &Op;
  }
}


template<class Scalar>
void Thyra::unwrap(
  const Teuchos::RCP<const LinearOpBase<Scalar> > &Op,
  Scalar *scalar,
  EOpTransp *transp,
  Teuchos::RCP<const LinearOpBase<Scalar> > *origOp
  )
{
#ifdef TEUCHOS_DEBUG
  TEST_FOR_EXCEPT( scalar==NULL );
  TEST_FOR_EXCEPT( transp==NULL );
  TEST_FOR_EXCEPT( origOp==NULL );
#endif
  typedef Teuchos::ScalarTraits<Scalar>  ST;
  Teuchos::RCP<const ScaledAdjointLinearOpBase<Scalar> >
    saOp = Teuchos::rcp_dynamic_cast<const ScaledAdjointLinearOpBase<Scalar> >(Op);
  if(saOp.get()) {
    *scalar = saOp->overallScalar();
    *transp = saOp->overallTransp();
    *origOp = saOp->getOrigOp();
  }
  else {
    *scalar = ST::one();
    *transp = NOTRANS;
    *origOp = Op;
  }
}

#endif	// THYRA_SCALED_ADJOINT_LINEAR_OP_BASE_HPP
